/*
 * (c) 2006 Thomas Maier-Komor
 * LICENSE: GPLv2, see file COPYING for details
 */

#include <assert.h>
#include <curses.h>
#include <errno.h>
#include <fcntl.h>
#include <stdarg.h>
#include <stdio.h>
#include <stdlib.h>
#include <strings.h>
#include <syslog.h>
#include <sys/wait.h>
#include <unistd.h>

#include "log.h"

static int Syslog = 0, Verbose = 0;


#ifdef DEBUG
static int Log = -1;

void dbug(const char *msg, ...)
{
	va_list val;
	char buf[8192];

	if (Log == -1)
		return;
	va_start(val,msg);
	vsprintf(buf,msg,val);
	va_end(val);
	if (Syslog) {
		syslog(LOG_DEBUG,buf);
	}
	(void) write(Log,buf,strlen(buf));
}
#endif


void info(const char *msg, ...)
{
	va_list val;
	char buf[8192];

	if (Verbose == 0)
		return;
	va_start(val,msg);
	(void) vsprintf(buf,msg,val);
	va_end(val);
	if (Syslog)
		syslog(LOG_INFO,buf);
	else
		(void) write(STDERR_FILENO,buf,strlen(buf));
#ifdef DEBUG
	if (Log != -1)
		(void) write(Log,buf,strlen(buf));
#endif
}


void warn(const char *msg, ...)
{
	va_list val;
	char buf[8192] = "warning: ";

	va_start(val,msg);
	(void) vsprintf(buf+9,msg,val);
	va_end(val);
	if (Syslog)
		syslog(LOG_WARNING,buf+9);
	else
		(void) write(STDERR_FILENO,buf,strlen(buf));
#ifdef DEBUG
	if (Log != -1)
		(void) write(Log,buf,strlen(buf));
#endif
}


void error(const char *msg, ...)
{
	va_list val;
	char buf[8192] = "error: ";

	va_start(val,msg);
	(void) vsprintf(buf+7,msg,val);
	va_end(val);
	if (Syslog)
		syslog(LOG_ERR,buf+7);
	else
		(void) write(STDERR_FILENO,buf,strlen(buf));
#ifdef DEBUG
	if (Log != -1)
		(void) write(Log,buf,strlen(buf));
#endif
	exit(EXIT_FAILURE);
}


void log2syslog(void)
{
	openlog("sysstatd",LOG_USER,0);
	Syslog = 1;
}


void setVerbose(void)
{
#ifdef DEBUG
	Log = open("sysstat.log",O_WRONLY|O_APPEND|O_CREAT,0666);
	if (Log == -1)
		error("could not create sysstat.log: %s",strerror(errno));
#endif
	Verbose = 1;
}

