/*
 * Copyright 2006, Thomas Maier-Komor
 * LICENSE: GPLv2, see file COPYING for details
 */

#ifndef SYSSTAT_H
#define SYSSTAT_H

#include "fsstats.h"
#include "userstat.h"

#define VERSION "20060721"

#ifdef __STDC__
#if __STDC_VERSION__ < 199901L
#define restrict
#endif
#else
#define restrict
#endif

typedef struct sysstat_s {
	char Hostinfo[256];
	clock_t TS, BootTime;
	unsigned long Ocpus, Ncpus, Devices;
	/* system load */
	double loadavg[3];
	/* cpu/sys percentages */
	double UserP, KernelP, IdleP;
	/* cpu/sys rates */
	double IntrR, IntrBlkR, XcallsR, SyscallR, SysexecR, SysforkR,
	       SysreadR, SyswriteR;
	/* cpu/vm rates */
	double ExecpginR, ExecpgoutR, ExecfreeR,
	       AnonpginR, AnonpgoutR, AnonfreeR,
	       InvSwtchR, PswitchR, MigrateR,
	       PgswapinR, PgswapoutR, ScanR;
	/* ip */
	double IpInR, IpOutR, NetInR, NetOutR;
	unsigned long IpInDiscards, IpOutDiscards, IpInErrs;
	/* storage */
	unsigned long long FsFree, Storage, Zsize, Zfree;
	unsigned long Zpools;
	/* unix/system_pages */
	unsigned long Pgsz;
	unsigned long Physmem, Pagesfree, Pageslocked, Pagestotal;
	/* swap (non-kstat info) */
	unsigned long SwapTotal, SwapFree;
	/* device_errors */
	unsigned long HardErrors, SoftErrors;
	/* device I/O rates */
	double DiskIR, DiskOR;
	/* nfs I/O rates */
	double NfsIR, NfsOR;
	/* nfsd call rate */
	double NfsdR;

	/* user statistics */
	userstat_t *us;
	/* filesystem statistics */
	fsstat_t *fs;
	unsigned numfs;

	/* used locally, to determine if stat has already been displayed */
	int displayed;
	/* support lists of sysstats */
	struct sysstat_s *next, *prev;
} sysstat_t;


extern void get_local_data(sysstat_t *);
extern void rundaemon(int);
extern void init_localstat(sysstat_t *);

extern unsigned Interval;

#endif
